You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@storm.apache.org by pt...@apache.org on 2015/12/01 23:05:18 UTC

[40/51] [partial] storm git commit: Update JStorm to latest release 2.1.0

http://git-wip-us.apache.org/repos/asf/storm/blob/7eaf0651/jstorm-core/src/main/java/backtype/storm/generated/NimbusStat.java
----------------------------------------------------------------------
diff --git a/jstorm-core/src/main/java/backtype/storm/generated/NimbusSummary.java b/jstorm-core/src/main/java/backtype/storm/generated/NimbusSummary.java
index 55b6e35..8e3173b 100644
--- a/jstorm-core/src/main/java/backtype/storm/generated/NimbusSummary.java
+++ b/jstorm-core/src/main/java/backtype/storm/generated/NimbusSummary.java
@@ -34,16 +34,16 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @SuppressWarnings({"cast", "rawtypes", "serial", "unchecked"})
-@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-7-27")
+@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-10-20")
 public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, NimbusSummary._Fields>, java.io.Serializable, Cloneable, Comparable<NimbusSummary> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("NimbusSummary");
 
-  private static final org.apache.thrift.protocol.TField NIMBUS_MASTER_FIELD_DESC = new org.apache.thrift.protocol.TField("nimbus_master", org.apache.thrift.protocol.TType.STRUCT, (short)1);
-  private static final org.apache.thrift.protocol.TField NIMBUS_SLAVES_FIELD_DESC = new org.apache.thrift.protocol.TField("nimbus_slaves", org.apache.thrift.protocol.TType.LIST, (short)2);
-  private static final org.apache.thrift.protocol.TField SUPERVISOR_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("supervisor_num", org.apache.thrift.protocol.TType.I32, (short)3);
-  private static final org.apache.thrift.protocol.TField TOTAL_PORT_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("total_port_num", org.apache.thrift.protocol.TType.I32, (short)4);
-  private static final org.apache.thrift.protocol.TField USED_PORT_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("used_port_num", org.apache.thrift.protocol.TType.I32, (short)5);
-  private static final org.apache.thrift.protocol.TField FREE_PORT_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("free_port_num", org.apache.thrift.protocol.TType.I32, (short)6);
+  private static final org.apache.thrift.protocol.TField NIMBUS_MASTER_FIELD_DESC = new org.apache.thrift.protocol.TField("nimbusMaster", org.apache.thrift.protocol.TType.STRUCT, (short)1);
+  private static final org.apache.thrift.protocol.TField NIMBUS_SLAVES_FIELD_DESC = new org.apache.thrift.protocol.TField("nimbusSlaves", org.apache.thrift.protocol.TType.LIST, (short)2);
+  private static final org.apache.thrift.protocol.TField SUPERVISOR_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("supervisorNum", org.apache.thrift.protocol.TType.I32, (short)3);
+  private static final org.apache.thrift.protocol.TField TOTAL_PORT_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("totalPortNum", org.apache.thrift.protocol.TType.I32, (short)4);
+  private static final org.apache.thrift.protocol.TField USED_PORT_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("usedPortNum", org.apache.thrift.protocol.TType.I32, (short)5);
+  private static final org.apache.thrift.protocol.TField FREE_PORT_NUM_FIELD_DESC = new org.apache.thrift.protocol.TField("freePortNum", org.apache.thrift.protocol.TType.I32, (short)6);
   private static final org.apache.thrift.protocol.TField VERSION_FIELD_DESC = new org.apache.thrift.protocol.TField("version", org.apache.thrift.protocol.TType.STRING, (short)7);
 
   private static final Map<Class<? extends IScheme>, SchemeFactory> schemes = new HashMap<Class<? extends IScheme>, SchemeFactory>();
@@ -52,22 +52,22 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
     schemes.put(TupleScheme.class, new NimbusSummaryTupleSchemeFactory());
   }
 
-  private NimbusStat nimbus_master; // required
-  private List<NimbusStat> nimbus_slaves; // required
-  private int supervisor_num; // required
-  private int total_port_num; // required
-  private int used_port_num; // required
-  private int free_port_num; // required
+  private NimbusStat nimbusMaster; // required
+  private List<NimbusStat> nimbusSlaves; // required
+  private int supervisorNum; // required
+  private int totalPortNum; // required
+  private int usedPortNum; // required
+  private int freePortNum; // required
   private String version; // required
 
   /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
   public enum _Fields implements org.apache.thrift.TFieldIdEnum {
-    NIMBUS_MASTER((short)1, "nimbus_master"),
-    NIMBUS_SLAVES((short)2, "nimbus_slaves"),
-    SUPERVISOR_NUM((short)3, "supervisor_num"),
-    TOTAL_PORT_NUM((short)4, "total_port_num"),
-    USED_PORT_NUM((short)5, "used_port_num"),
-    FREE_PORT_NUM((short)6, "free_port_num"),
+    NIMBUS_MASTER((short)1, "nimbusMaster"),
+    NIMBUS_SLAVES((short)2, "nimbusSlaves"),
+    SUPERVISOR_NUM((short)3, "supervisorNum"),
+    TOTAL_PORT_NUM((short)4, "totalPortNum"),
+    USED_PORT_NUM((short)5, "usedPortNum"),
+    FREE_PORT_NUM((short)6, "freePortNum"),
     VERSION((short)7, "version");
 
     private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();
@@ -137,26 +137,26 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
   }
 
   // isset id assignments
-  private static final int __SUPERVISOR_NUM_ISSET_ID = 0;
-  private static final int __TOTAL_PORT_NUM_ISSET_ID = 1;
-  private static final int __USED_PORT_NUM_ISSET_ID = 2;
-  private static final int __FREE_PORT_NUM_ISSET_ID = 3;
+  private static final int __SUPERVISORNUM_ISSET_ID = 0;
+  private static final int __TOTALPORTNUM_ISSET_ID = 1;
+  private static final int __USEDPORTNUM_ISSET_ID = 2;
+  private static final int __FREEPORTNUM_ISSET_ID = 3;
   private byte __isset_bitfield = 0;
   public static final Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> metaDataMap;
   static {
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
-    tmpMap.put(_Fields.NIMBUS_MASTER, new org.apache.thrift.meta_data.FieldMetaData("nimbus_master", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.NIMBUS_MASTER, new org.apache.thrift.meta_data.FieldMetaData("nimbusMaster", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.StructMetaData(org.apache.thrift.protocol.TType.STRUCT, NimbusStat.class)));
-    tmpMap.put(_Fields.NIMBUS_SLAVES, new org.apache.thrift.meta_data.FieldMetaData("nimbus_slaves", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.NIMBUS_SLAVES, new org.apache.thrift.meta_data.FieldMetaData("nimbusSlaves", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.ListMetaData(org.apache.thrift.protocol.TType.LIST, 
             new org.apache.thrift.meta_data.StructMetaData(org.apache.thrift.protocol.TType.STRUCT, NimbusStat.class))));
-    tmpMap.put(_Fields.SUPERVISOR_NUM, new org.apache.thrift.meta_data.FieldMetaData("supervisor_num", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.SUPERVISOR_NUM, new org.apache.thrift.meta_data.FieldMetaData("supervisorNum", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I32)));
-    tmpMap.put(_Fields.TOTAL_PORT_NUM, new org.apache.thrift.meta_data.FieldMetaData("total_port_num", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.TOTAL_PORT_NUM, new org.apache.thrift.meta_data.FieldMetaData("totalPortNum", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I32)));
-    tmpMap.put(_Fields.USED_PORT_NUM, new org.apache.thrift.meta_data.FieldMetaData("used_port_num", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.USED_PORT_NUM, new org.apache.thrift.meta_data.FieldMetaData("usedPortNum", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I32)));
-    tmpMap.put(_Fields.FREE_PORT_NUM, new org.apache.thrift.meta_data.FieldMetaData("free_port_num", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.FREE_PORT_NUM, new org.apache.thrift.meta_data.FieldMetaData("freePortNum", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I32)));
     tmpMap.put(_Fields.VERSION, new org.apache.thrift.meta_data.FieldMetaData("version", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
@@ -168,25 +168,25 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
   }
 
   public NimbusSummary(
-    NimbusStat nimbus_master,
-    List<NimbusStat> nimbus_slaves,
-    int supervisor_num,
-    int total_port_num,
-    int used_port_num,
-    int free_port_num,
+    NimbusStat nimbusMaster,
+    List<NimbusStat> nimbusSlaves,
+    int supervisorNum,
+    int totalPortNum,
+    int usedPortNum,
+    int freePortNum,
     String version)
   {
     this();
-    this.nimbus_master = nimbus_master;
-    this.nimbus_slaves = nimbus_slaves;
-    this.supervisor_num = supervisor_num;
-    set_supervisor_num_isSet(true);
-    this.total_port_num = total_port_num;
-    set_total_port_num_isSet(true);
-    this.used_port_num = used_port_num;
-    set_used_port_num_isSet(true);
-    this.free_port_num = free_port_num;
-    set_free_port_num_isSet(true);
+    this.nimbusMaster = nimbusMaster;
+    this.nimbusSlaves = nimbusSlaves;
+    this.supervisorNum = supervisorNum;
+    set_supervisorNum_isSet(true);
+    this.totalPortNum = totalPortNum;
+    set_totalPortNum_isSet(true);
+    this.usedPortNum = usedPortNum;
+    set_usedPortNum_isSet(true);
+    this.freePortNum = freePortNum;
+    set_freePortNum_isSet(true);
     this.version = version;
   }
 
@@ -195,20 +195,20 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
    */
   public NimbusSummary(NimbusSummary other) {
     __isset_bitfield = other.__isset_bitfield;
-    if (other.is_set_nimbus_master()) {
-      this.nimbus_master = new NimbusStat(other.nimbus_master);
+    if (other.is_set_nimbusMaster()) {
+      this.nimbusMaster = new NimbusStat(other.nimbusMaster);
     }
-    if (other.is_set_nimbus_slaves()) {
-      List<NimbusStat> __this__nimbus_slaves = new ArrayList<NimbusStat>(other.nimbus_slaves.size());
-      for (NimbusStat other_element : other.nimbus_slaves) {
-        __this__nimbus_slaves.add(new NimbusStat(other_element));
+    if (other.is_set_nimbusSlaves()) {
+      List<NimbusStat> __this__nimbusSlaves = new ArrayList<NimbusStat>(other.nimbusSlaves.size());
+      for (NimbusStat other_element : other.nimbusSlaves) {
+        __this__nimbusSlaves.add(new NimbusStat(other_element));
       }
-      this.nimbus_slaves = __this__nimbus_slaves;
+      this.nimbusSlaves = __this__nimbusSlaves;
     }
-    this.supervisor_num = other.supervisor_num;
-    this.total_port_num = other.total_port_num;
-    this.used_port_num = other.used_port_num;
-    this.free_port_num = other.free_port_num;
+    this.supervisorNum = other.supervisorNum;
+    this.totalPortNum = other.totalPortNum;
+    this.usedPortNum = other.usedPortNum;
+    this.freePortNum = other.freePortNum;
     if (other.is_set_version()) {
       this.version = other.version;
     }
@@ -220,166 +220,166 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
 
   @Override
   public void clear() {
-    this.nimbus_master = null;
-    this.nimbus_slaves = null;
-    set_supervisor_num_isSet(false);
-    this.supervisor_num = 0;
-    set_total_port_num_isSet(false);
-    this.total_port_num = 0;
-    set_used_port_num_isSet(false);
-    this.used_port_num = 0;
-    set_free_port_num_isSet(false);
-    this.free_port_num = 0;
+    this.nimbusMaster = null;
+    this.nimbusSlaves = null;
+    set_supervisorNum_isSet(false);
+    this.supervisorNum = 0;
+    set_totalPortNum_isSet(false);
+    this.totalPortNum = 0;
+    set_usedPortNum_isSet(false);
+    this.usedPortNum = 0;
+    set_freePortNum_isSet(false);
+    this.freePortNum = 0;
     this.version = null;
   }
 
-  public NimbusStat get_nimbus_master() {
-    return this.nimbus_master;
+  public NimbusStat get_nimbusMaster() {
+    return this.nimbusMaster;
   }
 
-  public void set_nimbus_master(NimbusStat nimbus_master) {
-    this.nimbus_master = nimbus_master;
+  public void set_nimbusMaster(NimbusStat nimbusMaster) {
+    this.nimbusMaster = nimbusMaster;
   }
 
-  public void unset_nimbus_master() {
-    this.nimbus_master = null;
+  public void unset_nimbusMaster() {
+    this.nimbusMaster = null;
   }
 
-  /** Returns true if field nimbus_master is set (has been assigned a value) and false otherwise */
-  public boolean is_set_nimbus_master() {
-    return this.nimbus_master != null;
+  /** Returns true if field nimbusMaster is set (has been assigned a value) and false otherwise */
+  public boolean is_set_nimbusMaster() {
+    return this.nimbusMaster != null;
   }
 
-  public void set_nimbus_master_isSet(boolean value) {
+  public void set_nimbusMaster_isSet(boolean value) {
     if (!value) {
-      this.nimbus_master = null;
+      this.nimbusMaster = null;
     }
   }
 
-  public int get_nimbus_slaves_size() {
-    return (this.nimbus_slaves == null) ? 0 : this.nimbus_slaves.size();
+  public int get_nimbusSlaves_size() {
+    return (this.nimbusSlaves == null) ? 0 : this.nimbusSlaves.size();
   }
 
-  public java.util.Iterator<NimbusStat> get_nimbus_slaves_iterator() {
-    return (this.nimbus_slaves == null) ? null : this.nimbus_slaves.iterator();
+  public java.util.Iterator<NimbusStat> get_nimbusSlaves_iterator() {
+    return (this.nimbusSlaves == null) ? null : this.nimbusSlaves.iterator();
   }
 
-  public void add_to_nimbus_slaves(NimbusStat elem) {
-    if (this.nimbus_slaves == null) {
-      this.nimbus_slaves = new ArrayList<NimbusStat>();
+  public void add_to_nimbusSlaves(NimbusStat elem) {
+    if (this.nimbusSlaves == null) {
+      this.nimbusSlaves = new ArrayList<NimbusStat>();
     }
-    this.nimbus_slaves.add(elem);
+    this.nimbusSlaves.add(elem);
   }
 
-  public List<NimbusStat> get_nimbus_slaves() {
-    return this.nimbus_slaves;
+  public List<NimbusStat> get_nimbusSlaves() {
+    return this.nimbusSlaves;
   }
 
-  public void set_nimbus_slaves(List<NimbusStat> nimbus_slaves) {
-    this.nimbus_slaves = nimbus_slaves;
+  public void set_nimbusSlaves(List<NimbusStat> nimbusSlaves) {
+    this.nimbusSlaves = nimbusSlaves;
   }
 
-  public void unset_nimbus_slaves() {
-    this.nimbus_slaves = null;
+  public void unset_nimbusSlaves() {
+    this.nimbusSlaves = null;
   }
 
-  /** Returns true if field nimbus_slaves is set (has been assigned a value) and false otherwise */
-  public boolean is_set_nimbus_slaves() {
-    return this.nimbus_slaves != null;
+  /** Returns true if field nimbusSlaves is set (has been assigned a value) and false otherwise */
+  public boolean is_set_nimbusSlaves() {
+    return this.nimbusSlaves != null;
   }
 
-  public void set_nimbus_slaves_isSet(boolean value) {
+  public void set_nimbusSlaves_isSet(boolean value) {
     if (!value) {
-      this.nimbus_slaves = null;
+      this.nimbusSlaves = null;
     }
   }
 
-  public int get_supervisor_num() {
-    return this.supervisor_num;
+  public int get_supervisorNum() {
+    return this.supervisorNum;
   }
 
-  public void set_supervisor_num(int supervisor_num) {
-    this.supervisor_num = supervisor_num;
-    set_supervisor_num_isSet(true);
+  public void set_supervisorNum(int supervisorNum) {
+    this.supervisorNum = supervisorNum;
+    set_supervisorNum_isSet(true);
   }
 
-  public void unset_supervisor_num() {
-    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __SUPERVISOR_NUM_ISSET_ID);
+  public void unset_supervisorNum() {
+    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __SUPERVISORNUM_ISSET_ID);
   }
 
-  /** Returns true if field supervisor_num is set (has been assigned a value) and false otherwise */
-  public boolean is_set_supervisor_num() {
-    return EncodingUtils.testBit(__isset_bitfield, __SUPERVISOR_NUM_ISSET_ID);
+  /** Returns true if field supervisorNum is set (has been assigned a value) and false otherwise */
+  public boolean is_set_supervisorNum() {
+    return EncodingUtils.testBit(__isset_bitfield, __SUPERVISORNUM_ISSET_ID);
   }
 
-  public void set_supervisor_num_isSet(boolean value) {
-    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __SUPERVISOR_NUM_ISSET_ID, value);
+  public void set_supervisorNum_isSet(boolean value) {
+    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __SUPERVISORNUM_ISSET_ID, value);
   }
 
-  public int get_total_port_num() {
-    return this.total_port_num;
+  public int get_totalPortNum() {
+    return this.totalPortNum;
   }
 
-  public void set_total_port_num(int total_port_num) {
-    this.total_port_num = total_port_num;
-    set_total_port_num_isSet(true);
+  public void set_totalPortNum(int totalPortNum) {
+    this.totalPortNum = totalPortNum;
+    set_totalPortNum_isSet(true);
   }
 
-  public void unset_total_port_num() {
-    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __TOTAL_PORT_NUM_ISSET_ID);
+  public void unset_totalPortNum() {
+    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __TOTALPORTNUM_ISSET_ID);
   }
 
-  /** Returns true if field total_port_num is set (has been assigned a value) and false otherwise */
-  public boolean is_set_total_port_num() {
-    return EncodingUtils.testBit(__isset_bitfield, __TOTAL_PORT_NUM_ISSET_ID);
+  /** Returns true if field totalPortNum is set (has been assigned a value) and false otherwise */
+  public boolean is_set_totalPortNum() {
+    return EncodingUtils.testBit(__isset_bitfield, __TOTALPORTNUM_ISSET_ID);
   }
 
-  public void set_total_port_num_isSet(boolean value) {
-    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __TOTAL_PORT_NUM_ISSET_ID, value);
+  public void set_totalPortNum_isSet(boolean value) {
+    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __TOTALPORTNUM_ISSET_ID, value);
   }
 
-  public int get_used_port_num() {
-    return this.used_port_num;
+  public int get_usedPortNum() {
+    return this.usedPortNum;
   }
 
-  public void set_used_port_num(int used_port_num) {
-    this.used_port_num = used_port_num;
-    set_used_port_num_isSet(true);
+  public void set_usedPortNum(int usedPortNum) {
+    this.usedPortNum = usedPortNum;
+    set_usedPortNum_isSet(true);
   }
 
-  public void unset_used_port_num() {
-    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __USED_PORT_NUM_ISSET_ID);
+  public void unset_usedPortNum() {
+    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __USEDPORTNUM_ISSET_ID);
   }
 
-  /** Returns true if field used_port_num is set (has been assigned a value) and false otherwise */
-  public boolean is_set_used_port_num() {
-    return EncodingUtils.testBit(__isset_bitfield, __USED_PORT_NUM_ISSET_ID);
+  /** Returns true if field usedPortNum is set (has been assigned a value) and false otherwise */
+  public boolean is_set_usedPortNum() {
+    return EncodingUtils.testBit(__isset_bitfield, __USEDPORTNUM_ISSET_ID);
   }
 
-  public void set_used_port_num_isSet(boolean value) {
-    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __USED_PORT_NUM_ISSET_ID, value);
+  public void set_usedPortNum_isSet(boolean value) {
+    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __USEDPORTNUM_ISSET_ID, value);
   }
 
-  public int get_free_port_num() {
-    return this.free_port_num;
+  public int get_freePortNum() {
+    return this.freePortNum;
   }
 
-  public void set_free_port_num(int free_port_num) {
-    this.free_port_num = free_port_num;
-    set_free_port_num_isSet(true);
+  public void set_freePortNum(int freePortNum) {
+    this.freePortNum = freePortNum;
+    set_freePortNum_isSet(true);
   }
 
-  public void unset_free_port_num() {
-    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __FREE_PORT_NUM_ISSET_ID);
+  public void unset_freePortNum() {
+    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __FREEPORTNUM_ISSET_ID);
   }
 
-  /** Returns true if field free_port_num is set (has been assigned a value) and false otherwise */
-  public boolean is_set_free_port_num() {
-    return EncodingUtils.testBit(__isset_bitfield, __FREE_PORT_NUM_ISSET_ID);
+  /** Returns true if field freePortNum is set (has been assigned a value) and false otherwise */
+  public boolean is_set_freePortNum() {
+    return EncodingUtils.testBit(__isset_bitfield, __FREEPORTNUM_ISSET_ID);
   }
 
-  public void set_free_port_num_isSet(boolean value) {
-    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __FREE_PORT_NUM_ISSET_ID, value);
+  public void set_freePortNum_isSet(boolean value) {
+    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __FREEPORTNUM_ISSET_ID, value);
   }
 
   public String get_version() {
@@ -409,49 +409,49 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
     switch (field) {
     case NIMBUS_MASTER:
       if (value == null) {
-        unset_nimbus_master();
+        unset_nimbusMaster();
       } else {
-        set_nimbus_master((NimbusStat)value);
+        set_nimbusMaster((NimbusStat)value);
       }
       break;
 
     case NIMBUS_SLAVES:
       if (value == null) {
-        unset_nimbus_slaves();
+        unset_nimbusSlaves();
       } else {
-        set_nimbus_slaves((List<NimbusStat>)value);
+        set_nimbusSlaves((List<NimbusStat>)value);
       }
       break;
 
     case SUPERVISOR_NUM:
       if (value == null) {
-        unset_supervisor_num();
+        unset_supervisorNum();
       } else {
-        set_supervisor_num((Integer)value);
+        set_supervisorNum((Integer)value);
       }
       break;
 
     case TOTAL_PORT_NUM:
       if (value == null) {
-        unset_total_port_num();
+        unset_totalPortNum();
       } else {
-        set_total_port_num((Integer)value);
+        set_totalPortNum((Integer)value);
       }
       break;
 
     case USED_PORT_NUM:
       if (value == null) {
-        unset_used_port_num();
+        unset_usedPortNum();
       } else {
-        set_used_port_num((Integer)value);
+        set_usedPortNum((Integer)value);
       }
       break;
 
     case FREE_PORT_NUM:
       if (value == null) {
-        unset_free_port_num();
+        unset_freePortNum();
       } else {
-        set_free_port_num((Integer)value);
+        set_freePortNum((Integer)value);
       }
       break;
 
@@ -469,22 +469,22 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
   public Object getFieldValue(_Fields field) {
     switch (field) {
     case NIMBUS_MASTER:
-      return get_nimbus_master();
+      return get_nimbusMaster();
 
     case NIMBUS_SLAVES:
-      return get_nimbus_slaves();
+      return get_nimbusSlaves();
 
     case SUPERVISOR_NUM:
-      return Integer.valueOf(get_supervisor_num());
+      return Integer.valueOf(get_supervisorNum());
 
     case TOTAL_PORT_NUM:
-      return Integer.valueOf(get_total_port_num());
+      return Integer.valueOf(get_totalPortNum());
 
     case USED_PORT_NUM:
-      return Integer.valueOf(get_used_port_num());
+      return Integer.valueOf(get_usedPortNum());
 
     case FREE_PORT_NUM:
-      return Integer.valueOf(get_free_port_num());
+      return Integer.valueOf(get_freePortNum());
 
     case VERSION:
       return get_version();
@@ -501,17 +501,17 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
 
     switch (field) {
     case NIMBUS_MASTER:
-      return is_set_nimbus_master();
+      return is_set_nimbusMaster();
     case NIMBUS_SLAVES:
-      return is_set_nimbus_slaves();
+      return is_set_nimbusSlaves();
     case SUPERVISOR_NUM:
-      return is_set_supervisor_num();
+      return is_set_supervisorNum();
     case TOTAL_PORT_NUM:
-      return is_set_total_port_num();
+      return is_set_totalPortNum();
     case USED_PORT_NUM:
-      return is_set_used_port_num();
+      return is_set_usedPortNum();
     case FREE_PORT_NUM:
-      return is_set_free_port_num();
+      return is_set_freePortNum();
     case VERSION:
       return is_set_version();
     }
@@ -531,57 +531,57 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
     if (that == null)
       return false;
 
-    boolean this_present_nimbus_master = true && this.is_set_nimbus_master();
-    boolean that_present_nimbus_master = true && that.is_set_nimbus_master();
-    if (this_present_nimbus_master || that_present_nimbus_master) {
-      if (!(this_present_nimbus_master && that_present_nimbus_master))
+    boolean this_present_nimbusMaster = true && this.is_set_nimbusMaster();
+    boolean that_present_nimbusMaster = true && that.is_set_nimbusMaster();
+    if (this_present_nimbusMaster || that_present_nimbusMaster) {
+      if (!(this_present_nimbusMaster && that_present_nimbusMaster))
         return false;
-      if (!this.nimbus_master.equals(that.nimbus_master))
+      if (!this.nimbusMaster.equals(that.nimbusMaster))
         return false;
     }
 
-    boolean this_present_nimbus_slaves = true && this.is_set_nimbus_slaves();
-    boolean that_present_nimbus_slaves = true && that.is_set_nimbus_slaves();
-    if (this_present_nimbus_slaves || that_present_nimbus_slaves) {
-      if (!(this_present_nimbus_slaves && that_present_nimbus_slaves))
+    boolean this_present_nimbusSlaves = true && this.is_set_nimbusSlaves();
+    boolean that_present_nimbusSlaves = true && that.is_set_nimbusSlaves();
+    if (this_present_nimbusSlaves || that_present_nimbusSlaves) {
+      if (!(this_present_nimbusSlaves && that_present_nimbusSlaves))
         return false;
-      if (!this.nimbus_slaves.equals(that.nimbus_slaves))
+      if (!this.nimbusSlaves.equals(that.nimbusSlaves))
         return false;
     }
 
-    boolean this_present_supervisor_num = true;
-    boolean that_present_supervisor_num = true;
-    if (this_present_supervisor_num || that_present_supervisor_num) {
-      if (!(this_present_supervisor_num && that_present_supervisor_num))
+    boolean this_present_supervisorNum = true;
+    boolean that_present_supervisorNum = true;
+    if (this_present_supervisorNum || that_present_supervisorNum) {
+      if (!(this_present_supervisorNum && that_present_supervisorNum))
         return false;
-      if (this.supervisor_num != that.supervisor_num)
+      if (this.supervisorNum != that.supervisorNum)
         return false;
     }
 
-    boolean this_present_total_port_num = true;
-    boolean that_present_total_port_num = true;
-    if (this_present_total_port_num || that_present_total_port_num) {
-      if (!(this_present_total_port_num && that_present_total_port_num))
+    boolean this_present_totalPortNum = true;
+    boolean that_present_totalPortNum = true;
+    if (this_present_totalPortNum || that_present_totalPortNum) {
+      if (!(this_present_totalPortNum && that_present_totalPortNum))
         return false;
-      if (this.total_port_num != that.total_port_num)
+      if (this.totalPortNum != that.totalPortNum)
         return false;
     }
 
-    boolean this_present_used_port_num = true;
-    boolean that_present_used_port_num = true;
-    if (this_present_used_port_num || that_present_used_port_num) {
-      if (!(this_present_used_port_num && that_present_used_port_num))
+    boolean this_present_usedPortNum = true;
+    boolean that_present_usedPortNum = true;
+    if (this_present_usedPortNum || that_present_usedPortNum) {
+      if (!(this_present_usedPortNum && that_present_usedPortNum))
         return false;
-      if (this.used_port_num != that.used_port_num)
+      if (this.usedPortNum != that.usedPortNum)
         return false;
     }
 
-    boolean this_present_free_port_num = true;
-    boolean that_present_free_port_num = true;
-    if (this_present_free_port_num || that_present_free_port_num) {
-      if (!(this_present_free_port_num && that_present_free_port_num))
+    boolean this_present_freePortNum = true;
+    boolean that_present_freePortNum = true;
+    if (this_present_freePortNum || that_present_freePortNum) {
+      if (!(this_present_freePortNum && that_present_freePortNum))
         return false;
-      if (this.free_port_num != that.free_port_num)
+      if (this.freePortNum != that.freePortNum)
         return false;
     }
 
@@ -601,35 +601,35 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
   public int hashCode() {
     List<Object> list = new ArrayList<Object>();
 
-    boolean present_nimbus_master = true && (is_set_nimbus_master());
-    list.add(present_nimbus_master);
-    if (present_nimbus_master)
-      list.add(nimbus_master);
+    boolean present_nimbusMaster = true && (is_set_nimbusMaster());
+    list.add(present_nimbusMaster);
+    if (present_nimbusMaster)
+      list.add(nimbusMaster);
 
-    boolean present_nimbus_slaves = true && (is_set_nimbus_slaves());
-    list.add(present_nimbus_slaves);
-    if (present_nimbus_slaves)
-      list.add(nimbus_slaves);
+    boolean present_nimbusSlaves = true && (is_set_nimbusSlaves());
+    list.add(present_nimbusSlaves);
+    if (present_nimbusSlaves)
+      list.add(nimbusSlaves);
 
-    boolean present_supervisor_num = true;
-    list.add(present_supervisor_num);
-    if (present_supervisor_num)
-      list.add(supervisor_num);
+    boolean present_supervisorNum = true;
+    list.add(present_supervisorNum);
+    if (present_supervisorNum)
+      list.add(supervisorNum);
 
-    boolean present_total_port_num = true;
-    list.add(present_total_port_num);
-    if (present_total_port_num)
-      list.add(total_port_num);
+    boolean present_totalPortNum = true;
+    list.add(present_totalPortNum);
+    if (present_totalPortNum)
+      list.add(totalPortNum);
 
-    boolean present_used_port_num = true;
-    list.add(present_used_port_num);
-    if (present_used_port_num)
-      list.add(used_port_num);
+    boolean present_usedPortNum = true;
+    list.add(present_usedPortNum);
+    if (present_usedPortNum)
+      list.add(usedPortNum);
 
-    boolean present_free_port_num = true;
-    list.add(present_free_port_num);
-    if (present_free_port_num)
-      list.add(free_port_num);
+    boolean present_freePortNum = true;
+    list.add(present_freePortNum);
+    if (present_freePortNum)
+      list.add(freePortNum);
 
     boolean present_version = true && (is_set_version());
     list.add(present_version);
@@ -647,62 +647,62 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
 
     int lastComparison = 0;
 
-    lastComparison = Boolean.valueOf(is_set_nimbus_master()).compareTo(other.is_set_nimbus_master());
+    lastComparison = Boolean.valueOf(is_set_nimbusMaster()).compareTo(other.is_set_nimbusMaster());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (is_set_nimbus_master()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.nimbus_master, other.nimbus_master);
+    if (is_set_nimbusMaster()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.nimbusMaster, other.nimbusMaster);
       if (lastComparison != 0) {
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(is_set_nimbus_slaves()).compareTo(other.is_set_nimbus_slaves());
+    lastComparison = Boolean.valueOf(is_set_nimbusSlaves()).compareTo(other.is_set_nimbusSlaves());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (is_set_nimbus_slaves()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.nimbus_slaves, other.nimbus_slaves);
+    if (is_set_nimbusSlaves()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.nimbusSlaves, other.nimbusSlaves);
       if (lastComparison != 0) {
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(is_set_supervisor_num()).compareTo(other.is_set_supervisor_num());
+    lastComparison = Boolean.valueOf(is_set_supervisorNum()).compareTo(other.is_set_supervisorNum());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (is_set_supervisor_num()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.supervisor_num, other.supervisor_num);
+    if (is_set_supervisorNum()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.supervisorNum, other.supervisorNum);
       if (lastComparison != 0) {
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(is_set_total_port_num()).compareTo(other.is_set_total_port_num());
+    lastComparison = Boolean.valueOf(is_set_totalPortNum()).compareTo(other.is_set_totalPortNum());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (is_set_total_port_num()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.total_port_num, other.total_port_num);
+    if (is_set_totalPortNum()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.totalPortNum, other.totalPortNum);
       if (lastComparison != 0) {
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(is_set_used_port_num()).compareTo(other.is_set_used_port_num());
+    lastComparison = Boolean.valueOf(is_set_usedPortNum()).compareTo(other.is_set_usedPortNum());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (is_set_used_port_num()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.used_port_num, other.used_port_num);
+    if (is_set_usedPortNum()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.usedPortNum, other.usedPortNum);
       if (lastComparison != 0) {
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(is_set_free_port_num()).compareTo(other.is_set_free_port_num());
+    lastComparison = Boolean.valueOf(is_set_freePortNum()).compareTo(other.is_set_freePortNum());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (is_set_free_port_num()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.free_port_num, other.free_port_num);
+    if (is_set_freePortNum()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.freePortNum, other.freePortNum);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -724,11 +724,11 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
     return _Fields.findByThriftId(fieldId);
   }
 
-  public void read(org.apache.thrift.protocol.TProtocol iprot) throws org.apache.thrift.TException {
+  public void read(org.apache.thrift.protocol.TProtocol iprot) throws TException {
     schemes.get(iprot.getScheme()).getScheme().read(iprot, this);
   }
 
-  public void write(org.apache.thrift.protocol.TProtocol oprot) throws org.apache.thrift.TException {
+  public void write(org.apache.thrift.protocol.TProtocol oprot) throws TException {
     schemes.get(oprot.getScheme()).getScheme().write(oprot, this);
   }
 
@@ -737,36 +737,36 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
     StringBuilder sb = new StringBuilder("NimbusSummary(");
     boolean first = true;
 
-    sb.append("nimbus_master:");
-    if (this.nimbus_master == null) {
+    sb.append("nimbusMaster:");
+    if (this.nimbusMaster == null) {
       sb.append("null");
     } else {
-      sb.append(this.nimbus_master);
+      sb.append(this.nimbusMaster);
     }
     first = false;
     if (!first) sb.append(", ");
-    sb.append("nimbus_slaves:");
-    if (this.nimbus_slaves == null) {
+    sb.append("nimbusSlaves:");
+    if (this.nimbusSlaves == null) {
       sb.append("null");
     } else {
-      sb.append(this.nimbus_slaves);
+      sb.append(this.nimbusSlaves);
     }
     first = false;
     if (!first) sb.append(", ");
-    sb.append("supervisor_num:");
-    sb.append(this.supervisor_num);
+    sb.append("supervisorNum:");
+    sb.append(this.supervisorNum);
     first = false;
     if (!first) sb.append(", ");
-    sb.append("total_port_num:");
-    sb.append(this.total_port_num);
+    sb.append("totalPortNum:");
+    sb.append(this.totalPortNum);
     first = false;
     if (!first) sb.append(", ");
-    sb.append("used_port_num:");
-    sb.append(this.used_port_num);
+    sb.append("usedPortNum:");
+    sb.append(this.usedPortNum);
     first = false;
     if (!first) sb.append(", ");
-    sb.append("free_port_num:");
-    sb.append(this.free_port_num);
+    sb.append("freePortNum:");
+    sb.append(this.freePortNum);
     first = false;
     if (!first) sb.append(", ");
     sb.append("version:");
@@ -780,46 +780,46 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
     return sb.toString();
   }
 
-  public void validate() throws org.apache.thrift.TException {
+  public void validate() throws TException {
     // check for required fields
-    if (!is_set_nimbus_master()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'nimbus_master' is unset! Struct:" + toString());
+    if (!is_set_nimbusMaster()) {
+      throw new TProtocolException("Required field 'nimbusMaster' is unset! Struct:" + toString());
     }
 
-    if (!is_set_nimbus_slaves()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'nimbus_slaves' is unset! Struct:" + toString());
+    if (!is_set_nimbusSlaves()) {
+      throw new TProtocolException("Required field 'nimbusSlaves' is unset! Struct:" + toString());
     }
 
-    if (!is_set_supervisor_num()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'supervisor_num' is unset! Struct:" + toString());
+    if (!is_set_supervisorNum()) {
+      throw new TProtocolException("Required field 'supervisorNum' is unset! Struct:" + toString());
     }
 
-    if (!is_set_total_port_num()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'total_port_num' is unset! Struct:" + toString());
+    if (!is_set_totalPortNum()) {
+      throw new TProtocolException("Required field 'totalPortNum' is unset! Struct:" + toString());
     }
 
-    if (!is_set_used_port_num()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'used_port_num' is unset! Struct:" + toString());
+    if (!is_set_usedPortNum()) {
+      throw new TProtocolException("Required field 'usedPortNum' is unset! Struct:" + toString());
     }
 
-    if (!is_set_free_port_num()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'free_port_num' is unset! Struct:" + toString());
+    if (!is_set_freePortNum()) {
+      throw new TProtocolException("Required field 'freePortNum' is unset! Struct:" + toString());
     }
 
     if (!is_set_version()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'version' is unset! Struct:" + toString());
+      throw new TProtocolException("Required field 'version' is unset! Struct:" + toString());
     }
 
     // check for sub-struct validity
-    if (nimbus_master != null) {
-      nimbus_master.validate();
+    if (nimbusMaster != null) {
+      nimbusMaster.validate();
     }
   }
 
   private void writeObject(java.io.ObjectOutputStream out) throws java.io.IOException {
     try {
       write(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(out)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -829,7 +829,7 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
       // it doesn't seem like you should have to do this, but java serialization is wacky, and doesn't call the default constructor.
       __isset_bitfield = 0;
       read(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(in)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -842,7 +842,7 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
 
   private static class NimbusSummaryStandardScheme extends StandardScheme<NimbusSummary> {
 
-    public void read(org.apache.thrift.protocol.TProtocol iprot, NimbusSummary struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol iprot, NimbusSummary struct) throws TException {
       org.apache.thrift.protocol.TField schemeField;
       iprot.readStructBegin();
       while (true)
@@ -854,9 +854,9 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
         switch (schemeField.id) {
           case 1: // NIMBUS_MASTER
             if (schemeField.type == org.apache.thrift.protocol.TType.STRUCT) {
-              struct.nimbus_master = new NimbusStat();
-              struct.nimbus_master.read(iprot);
-              struct.set_nimbus_master_isSet(true);
+              struct.nimbusMaster = new NimbusStat();
+              struct.nimbusMaster.read(iprot);
+              struct.set_nimbusMaster_isSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -865,49 +865,49 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
             if (schemeField.type == org.apache.thrift.protocol.TType.LIST) {
               {
                 org.apache.thrift.protocol.TList _list74 = iprot.readListBegin();
-                struct.nimbus_slaves = new ArrayList<NimbusStat>(_list74.size);
+                struct.nimbusSlaves = new ArrayList<NimbusStat>(_list74.size);
                 NimbusStat _elem75;
                 for (int _i76 = 0; _i76 < _list74.size; ++_i76)
                 {
                   _elem75 = new NimbusStat();
                   _elem75.read(iprot);
-                  struct.nimbus_slaves.add(_elem75);
+                  struct.nimbusSlaves.add(_elem75);
                 }
                 iprot.readListEnd();
               }
-              struct.set_nimbus_slaves_isSet(true);
+              struct.set_nimbusSlaves_isSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
             break;
           case 3: // SUPERVISOR_NUM
             if (schemeField.type == org.apache.thrift.protocol.TType.I32) {
-              struct.supervisor_num = iprot.readI32();
-              struct.set_supervisor_num_isSet(true);
+              struct.supervisorNum = iprot.readI32();
+              struct.set_supervisorNum_isSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
             break;
           case 4: // TOTAL_PORT_NUM
             if (schemeField.type == org.apache.thrift.protocol.TType.I32) {
-              struct.total_port_num = iprot.readI32();
-              struct.set_total_port_num_isSet(true);
+              struct.totalPortNum = iprot.readI32();
+              struct.set_totalPortNum_isSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
             break;
           case 5: // USED_PORT_NUM
             if (schemeField.type == org.apache.thrift.protocol.TType.I32) {
-              struct.used_port_num = iprot.readI32();
-              struct.set_used_port_num_isSet(true);
+              struct.usedPortNum = iprot.readI32();
+              struct.set_usedPortNum_isSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
             break;
           case 6: // FREE_PORT_NUM
             if (schemeField.type == org.apache.thrift.protocol.TType.I32) {
-              struct.free_port_num = iprot.readI32();
-              struct.set_free_port_num_isSet(true);
+              struct.freePortNum = iprot.readI32();
+              struct.set_freePortNum_isSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -929,20 +929,20 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
       struct.validate();
     }
 
-    public void write(org.apache.thrift.protocol.TProtocol oprot, NimbusSummary struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol oprot, NimbusSummary struct) throws TException {
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
-      if (struct.nimbus_master != null) {
+      if (struct.nimbusMaster != null) {
         oprot.writeFieldBegin(NIMBUS_MASTER_FIELD_DESC);
-        struct.nimbus_master.write(oprot);
+        struct.nimbusMaster.write(oprot);
         oprot.writeFieldEnd();
       }
-      if (struct.nimbus_slaves != null) {
+      if (struct.nimbusSlaves != null) {
         oprot.writeFieldBegin(NIMBUS_SLAVES_FIELD_DESC);
         {
-          oprot.writeListBegin(new org.apache.thrift.protocol.TList(org.apache.thrift.protocol.TType.STRUCT, struct.nimbus_slaves.size()));
-          for (NimbusStat _iter77 : struct.nimbus_slaves)
+          oprot.writeListBegin(new org.apache.thrift.protocol.TList(org.apache.thrift.protocol.TType.STRUCT, struct.nimbusSlaves.size()));
+          for (NimbusStat _iter77 : struct.nimbusSlaves)
           {
             _iter77.write(oprot);
           }
@@ -951,16 +951,16 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
         oprot.writeFieldEnd();
       }
       oprot.writeFieldBegin(SUPERVISOR_NUM_FIELD_DESC);
-      oprot.writeI32(struct.supervisor_num);
+      oprot.writeI32(struct.supervisorNum);
       oprot.writeFieldEnd();
       oprot.writeFieldBegin(TOTAL_PORT_NUM_FIELD_DESC);
-      oprot.writeI32(struct.total_port_num);
+      oprot.writeI32(struct.totalPortNum);
       oprot.writeFieldEnd();
       oprot.writeFieldBegin(USED_PORT_NUM_FIELD_DESC);
-      oprot.writeI32(struct.used_port_num);
+      oprot.writeI32(struct.usedPortNum);
       oprot.writeFieldEnd();
       oprot.writeFieldBegin(FREE_PORT_NUM_FIELD_DESC);
-      oprot.writeI32(struct.free_port_num);
+      oprot.writeI32(struct.freePortNum);
       oprot.writeFieldEnd();
       if (struct.version != null) {
         oprot.writeFieldBegin(VERSION_FIELD_DESC);
@@ -982,49 +982,49 @@ public class NimbusSummary implements org.apache.thrift.TBase<NimbusSummary, Nim
   private static class NimbusSummaryTupleScheme extends TupleScheme<NimbusSummary> {
 
     @Override
-    public void write(org.apache.thrift.protocol.TProtocol prot, NimbusSummary struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol prot, NimbusSummary struct) throws TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
-      struct.nimbus_master.write(oprot);
+      struct.nimbusMaster.write(oprot);
       {
-        oprot.writeI32(struct.nimbus_slaves.size());
-        for (NimbusStat _iter78 : struct.nimbus_slaves)
+        oprot.writeI32(struct.nimbusSlaves.size());
+        for (NimbusStat _iter78 : struct.nimbusSlaves)
         {
           _iter78.write(oprot);
         }
       }
-      oprot.writeI32(struct.supervisor_num);
-      oprot.writeI32(struct.total_port_num);
-      oprot.writeI32(struct.used_port_num);
-      oprot.writeI32(struct.free_port_num);
+      oprot.writeI32(struct.supervisorNum);
+      oprot.writeI32(struct.totalPortNum);
+      oprot.writeI32(struct.usedPortNum);
+      oprot.writeI32(struct.freePortNum);
       oprot.writeString(struct.version);
     }
 
     @Override
-    public void read(org.apache.thrift.protocol.TProtocol prot, NimbusSummary struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol prot, NimbusSummary struct) throws TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
-      struct.nimbus_master = new NimbusStat();
-      struct.nimbus_master.read(iprot);
-      struct.set_nimbus_master_isSet(true);
+      struct.nimbusMaster = new NimbusStat();
+      struct.nimbusMaster.read(iprot);
+      struct.set_nimbusMaster_isSet(true);
       {
         org.apache.thrift.protocol.TList _list79 = new org.apache.thrift.protocol.TList(org.apache.thrift.protocol.TType.STRUCT, iprot.readI32());
-        struct.nimbus_slaves = new ArrayList<NimbusStat>(_list79.size);
+        struct.nimbusSlaves = new ArrayList<NimbusStat>(_list79.size);
         NimbusStat _elem80;
         for (int _i81 = 0; _i81 < _list79.size; ++_i81)
         {
           _elem80 = new NimbusStat();
           _elem80.read(iprot);
-          struct.nimbus_slaves.add(_elem80);
+          struct.nimbusSlaves.add(_elem80);
         }
       }
-      struct.set_nimbus_slaves_isSet(true);
-      struct.supervisor_num = iprot.readI32();
-      struct.set_supervisor_num_isSet(true);
-      struct.total_port_num = iprot.readI32();
-      struct.set_total_port_num_isSet(true);
-      struct.used_port_num = iprot.readI32();
-      struct.set_used_port_num_isSet(true);
-      struct.free_port_num = iprot.readI32();
-      struct.set_free_port_num_isSet(true);
+      struct.set_nimbusSlaves_isSet(true);
+      struct.supervisorNum = iprot.readI32();
+      struct.set_supervisorNum_isSet(true);
+      struct.totalPortNum = iprot.readI32();
+      struct.set_totalPortNum_isSet(true);
+      struct.usedPortNum = iprot.readI32();
+      struct.set_usedPortNum_isSet(true);
+      struct.freePortNum = iprot.readI32();
+      struct.set_freePortNum_isSet(true);
       struct.version = iprot.readString();
       struct.set_version_isSet(true);
     }

http://git-wip-us.apache.org/repos/asf/storm/blob/7eaf0651/jstorm-core/src/main/java/backtype/storm/generated/NotAliveException.java
----------------------------------------------------------------------
diff --git a/jstorm-core/src/main/java/backtype/storm/generated/NotAliveException.java b/jstorm-core/src/main/java/backtype/storm/generated/NotAliveException.java
index ae0f056..d306d08 100644
--- a/jstorm-core/src/main/java/backtype/storm/generated/NotAliveException.java
+++ b/jstorm-core/src/main/java/backtype/storm/generated/NotAliveException.java
@@ -34,7 +34,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @SuppressWarnings({"cast", "rawtypes", "serial", "unchecked"})
-@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-7-27")
+@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-10-20")
 public class NotAliveException extends TException implements org.apache.thrift.TBase<NotAliveException, NotAliveException._Fields>, java.io.Serializable, Cloneable, Comparable<NotAliveException> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("NotAliveException");
 
@@ -264,11 +264,11 @@ public class NotAliveException extends TException implements org.apache.thrift.T
     return _Fields.findByThriftId(fieldId);
   }
 
-  public void read(org.apache.thrift.protocol.TProtocol iprot) throws org.apache.thrift.TException {
+  public void read(org.apache.thrift.protocol.TProtocol iprot) throws TException {
     schemes.get(iprot.getScheme()).getScheme().read(iprot, this);
   }
 
-  public void write(org.apache.thrift.protocol.TProtocol oprot) throws org.apache.thrift.TException {
+  public void write(org.apache.thrift.protocol.TProtocol oprot) throws TException {
     schemes.get(oprot.getScheme()).getScheme().write(oprot, this);
   }
 
@@ -288,10 +288,10 @@ public class NotAliveException extends TException implements org.apache.thrift.T
     return sb.toString();
   }
 
-  public void validate() throws org.apache.thrift.TException {
+  public void validate() throws TException {
     // check for required fields
     if (!is_set_msg()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'msg' is unset! Struct:" + toString());
+      throw new TProtocolException("Required field 'msg' is unset! Struct:" + toString());
     }
 
     // check for sub-struct validity
@@ -300,7 +300,7 @@ public class NotAliveException extends TException implements org.apache.thrift.T
   private void writeObject(java.io.ObjectOutputStream out) throws java.io.IOException {
     try {
       write(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(out)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -308,7 +308,7 @@ public class NotAliveException extends TException implements org.apache.thrift.T
   private void readObject(java.io.ObjectInputStream in) throws java.io.IOException, ClassNotFoundException {
     try {
       read(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(in)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -321,7 +321,7 @@ public class NotAliveException extends TException implements org.apache.thrift.T
 
   private static class NotAliveExceptionStandardScheme extends StandardScheme<NotAliveException> {
 
-    public void read(org.apache.thrift.protocol.TProtocol iprot, NotAliveException struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol iprot, NotAliveException struct) throws TException {
       org.apache.thrift.protocol.TField schemeField;
       iprot.readStructBegin();
       while (true)
@@ -348,7 +348,7 @@ public class NotAliveException extends TException implements org.apache.thrift.T
       struct.validate();
     }
 
-    public void write(org.apache.thrift.protocol.TProtocol oprot, NotAliveException struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol oprot, NotAliveException struct) throws TException {
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
@@ -372,13 +372,13 @@ public class NotAliveException extends TException implements org.apache.thrift.T
   private static class NotAliveExceptionTupleScheme extends TupleScheme<NotAliveException> {
 
     @Override
-    public void write(org.apache.thrift.protocol.TProtocol prot, NotAliveException struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol prot, NotAliveException struct) throws TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
       oprot.writeString(struct.msg);
     }
 
     @Override
-    public void read(org.apache.thrift.protocol.TProtocol prot, NotAliveException struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol prot, NotAliveException struct) throws TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
       struct.msg = iprot.readString();
       struct.set_msg_isSet(true);

http://git-wip-us.apache.org/repos/asf/storm/blob/7eaf0651/jstorm-core/src/main/java/backtype/storm/generated/NullStruct.java
----------------------------------------------------------------------
diff --git a/jstorm-core/src/main/java/backtype/storm/generated/NullStruct.java b/jstorm-core/src/main/java/backtype/storm/generated/NullStruct.java
index 0494eb2..f9e958d 100644
--- a/jstorm-core/src/main/java/backtype/storm/generated/NullStruct.java
+++ b/jstorm-core/src/main/java/backtype/storm/generated/NullStruct.java
@@ -34,7 +34,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @SuppressWarnings({"cast", "rawtypes", "serial", "unchecked"})
-@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-7-27")
+@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-10-20")
 public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruct._Fields>, java.io.Serializable, Cloneable, Comparable<NullStruct> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("NullStruct");
 
@@ -185,11 +185,11 @@ public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruc
     return _Fields.findByThriftId(fieldId);
   }
 
-  public void read(org.apache.thrift.protocol.TProtocol iprot) throws org.apache.thrift.TException {
+  public void read(org.apache.thrift.protocol.TProtocol iprot) throws TException {
     schemes.get(iprot.getScheme()).getScheme().read(iprot, this);
   }
 
-  public void write(org.apache.thrift.protocol.TProtocol oprot) throws org.apache.thrift.TException {
+  public void write(org.apache.thrift.protocol.TProtocol oprot) throws TException {
     schemes.get(oprot.getScheme()).getScheme().write(oprot, this);
   }
 
@@ -202,7 +202,7 @@ public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruc
     return sb.toString();
   }
 
-  public void validate() throws org.apache.thrift.TException {
+  public void validate() throws TException {
     // check for required fields
     // check for sub-struct validity
   }
@@ -210,7 +210,7 @@ public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruc
   private void writeObject(java.io.ObjectOutputStream out) throws java.io.IOException {
     try {
       write(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(out)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -218,7 +218,7 @@ public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruc
   private void readObject(java.io.ObjectInputStream in) throws java.io.IOException, ClassNotFoundException {
     try {
       read(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(in)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -231,7 +231,7 @@ public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruc
 
   private static class NullStructStandardScheme extends StandardScheme<NullStruct> {
 
-    public void read(org.apache.thrift.protocol.TProtocol iprot, NullStruct struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol iprot, NullStruct struct) throws TException {
       org.apache.thrift.protocol.TField schemeField;
       iprot.readStructBegin();
       while (true)
@@ -250,7 +250,7 @@ public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruc
       struct.validate();
     }
 
-    public void write(org.apache.thrift.protocol.TProtocol oprot, NullStruct struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol oprot, NullStruct struct) throws TException {
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
@@ -269,12 +269,12 @@ public class NullStruct implements org.apache.thrift.TBase<NullStruct, NullStruc
   private static class NullStructTupleScheme extends TupleScheme<NullStruct> {
 
     @Override
-    public void write(org.apache.thrift.protocol.TProtocol prot, NullStruct struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol prot, NullStruct struct) throws TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
     }
 
     @Override
-    public void read(org.apache.thrift.protocol.TProtocol prot, NullStruct struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol prot, NullStruct struct) throws TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
     }
   }

http://git-wip-us.apache.org/repos/asf/storm/blob/7eaf0651/jstorm-core/src/main/java/backtype/storm/generated/RebalanceOptions.java
----------------------------------------------------------------------
diff --git a/jstorm-core/src/main/java/backtype/storm/generated/RebalanceOptions.java b/jstorm-core/src/main/java/backtype/storm/generated/RebalanceOptions.java
index 3348189..287559e 100644
--- a/jstorm-core/src/main/java/backtype/storm/generated/RebalanceOptions.java
+++ b/jstorm-core/src/main/java/backtype/storm/generated/RebalanceOptions.java
@@ -34,7 +34,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @SuppressWarnings({"cast", "rawtypes", "serial", "unchecked"})
-@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-7-27")
+@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-10-20")
 public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOptions, RebalanceOptions._Fields>, java.io.Serializable, Cloneable, Comparable<RebalanceOptions> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("RebalanceOptions");
 
@@ -400,11 +400,11 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
     return _Fields.findByThriftId(fieldId);
   }
 
-  public void read(org.apache.thrift.protocol.TProtocol iprot) throws org.apache.thrift.TException {
+  public void read(org.apache.thrift.protocol.TProtocol iprot) throws TException {
     schemes.get(iprot.getScheme()).getScheme().read(iprot, this);
   }
 
-  public void write(org.apache.thrift.protocol.TProtocol oprot) throws org.apache.thrift.TException {
+  public void write(org.apache.thrift.protocol.TProtocol oprot) throws TException {
     schemes.get(oprot.getScheme()).getScheme().write(oprot, this);
   }
 
@@ -438,7 +438,7 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
     return sb.toString();
   }
 
-  public void validate() throws org.apache.thrift.TException {
+  public void validate() throws TException {
     // check for required fields
     // check for sub-struct validity
   }
@@ -446,7 +446,7 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
   private void writeObject(java.io.ObjectOutputStream out) throws java.io.IOException {
     try {
       write(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(out)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -456,7 +456,7 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
       // it doesn't seem like you should have to do this, but java serialization is wacky, and doesn't call the default constructor.
       __isset_bitfield = 0;
       read(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(in)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -469,7 +469,7 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
 
   private static class RebalanceOptionsStandardScheme extends StandardScheme<RebalanceOptions> {
 
-    public void read(org.apache.thrift.protocol.TProtocol iprot, RebalanceOptions struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol iprot, RebalanceOptions struct) throws TException {
       org.apache.thrift.protocol.TField schemeField;
       iprot.readStructBegin();
       while (true)
@@ -512,7 +512,7 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
       struct.validate();
     }
 
-    public void write(org.apache.thrift.protocol.TProtocol oprot, RebalanceOptions struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol oprot, RebalanceOptions struct) throws TException {
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
@@ -548,7 +548,7 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
   private static class RebalanceOptionsTupleScheme extends TupleScheme<RebalanceOptions> {
 
     @Override
-    public void write(org.apache.thrift.protocol.TProtocol prot, RebalanceOptions struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol prot, RebalanceOptions struct) throws TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
       BitSet optionals = new BitSet();
       if (struct.is_set_wait_secs()) {
@@ -573,7 +573,7 @@ public class RebalanceOptions implements org.apache.thrift.TBase<RebalanceOption
     }
 
     @Override
-    public void read(org.apache.thrift.protocol.TProtocol prot, RebalanceOptions struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol prot, RebalanceOptions struct) throws TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
       BitSet incoming = iprot.readBitSet(3);
       if (incoming.get(0)) {

http://git-wip-us.apache.org/repos/asf/storm/blob/7eaf0651/jstorm-core/src/main/java/backtype/storm/generated/ShellComponent.java
----------------------------------------------------------------------
diff --git a/jstorm-core/src/main/java/backtype/storm/generated/ShellComponent.java b/jstorm-core/src/main/java/backtype/storm/generated/ShellComponent.java
index 1f9e827..adec27e 100644
--- a/jstorm-core/src/main/java/backtype/storm/generated/ShellComponent.java
+++ b/jstorm-core/src/main/java/backtype/storm/generated/ShellComponent.java
@@ -34,7 +34,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @SuppressWarnings({"cast", "rawtypes", "serial", "unchecked"})
-@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-7-27")
+@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-10-20")
 public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, ShellComponent._Fields>, java.io.Serializable, Cloneable, Comparable<ShellComponent> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("ShellComponent");
 
@@ -337,11 +337,11 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
     return _Fields.findByThriftId(fieldId);
   }
 
-  public void read(org.apache.thrift.protocol.TProtocol iprot) throws org.apache.thrift.TException {
+  public void read(org.apache.thrift.protocol.TProtocol iprot) throws TException {
     schemes.get(iprot.getScheme()).getScheme().read(iprot, this);
   }
 
-  public void write(org.apache.thrift.protocol.TProtocol oprot) throws org.apache.thrift.TException {
+  public void write(org.apache.thrift.protocol.TProtocol oprot) throws TException {
     schemes.get(oprot.getScheme()).getScheme().write(oprot, this);
   }
 
@@ -369,7 +369,7 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
     return sb.toString();
   }
 
-  public void validate() throws org.apache.thrift.TException {
+  public void validate() throws TException {
     // check for required fields
     // check for sub-struct validity
   }
@@ -377,7 +377,7 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
   private void writeObject(java.io.ObjectOutputStream out) throws java.io.IOException {
     try {
       write(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(out)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -385,7 +385,7 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
   private void readObject(java.io.ObjectInputStream in) throws java.io.IOException, ClassNotFoundException {
     try {
       read(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(in)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -398,7 +398,7 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
 
   private static class ShellComponentStandardScheme extends StandardScheme<ShellComponent> {
 
-    public void read(org.apache.thrift.protocol.TProtocol iprot, ShellComponent struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol iprot, ShellComponent struct) throws TException {
       org.apache.thrift.protocol.TField schemeField;
       iprot.readStructBegin();
       while (true)
@@ -433,7 +433,7 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
       struct.validate();
     }
 
-    public void write(org.apache.thrift.protocol.TProtocol oprot, ShellComponent struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol oprot, ShellComponent struct) throws TException {
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
@@ -462,7 +462,7 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
   private static class ShellComponentTupleScheme extends TupleScheme<ShellComponent> {
 
     @Override
-    public void write(org.apache.thrift.protocol.TProtocol prot, ShellComponent struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol prot, ShellComponent struct) throws TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
       BitSet optionals = new BitSet();
       if (struct.is_set_execution_command()) {
@@ -481,7 +481,7 @@ public class ShellComponent implements org.apache.thrift.TBase<ShellComponent, S
     }
 
     @Override
-    public void read(org.apache.thrift.protocol.TProtocol prot, ShellComponent struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol prot, ShellComponent struct) throws TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
       BitSet incoming = iprot.readBitSet(2);
       if (incoming.get(0)) {
diff --git a/jstorm-core/src/main/java/backtype/storm/generated/NimbusStat.java b/jstorm-core/src/main/java/backtype/storm/generated/NimbusStat.java
index 90badb6..9ab9bcb 100644
--- a/jstorm-core/src/main/java/backtype/storm/generated/NimbusStat.java
+++ b/jstorm-core/src/main/java/backtype/storm/generated/NimbusStat.java
@@ -34,12 +34,12 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @SuppressWarnings({"cast", "rawtypes", "serial", "unchecked"})
-@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-7-27")
+@Generated(value = "Autogenerated by Thrift Compiler (0.9.2)", date = "2015-10-20")
 public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusStat._Fields>, java.io.Serializable, Cloneable, Comparable<NimbusStat> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("NimbusStat");
 
   private static final org.apache.thrift.protocol.TField HOST_FIELD_DESC = new org.apache.thrift.protocol.TField("host", org.apache.thrift.protocol.TType.STRING, (short)1);
-  private static final org.apache.thrift.protocol.TField UPTIME_SECS_FIELD_DESC = new org.apache.thrift.protocol.TField("uptime_secs", org.apache.thrift.protocol.TType.STRING, (short)2);
+  private static final org.apache.thrift.protocol.TField UPTIME_SECS_FIELD_DESC = new org.apache.thrift.protocol.TField("uptimeSecs", org.apache.thrift.protocol.TType.STRING, (short)2);
 
   private static final Map<Class<? extends IScheme>, SchemeFactory> schemes = new HashMap<Class<? extends IScheme>, SchemeFactory>();
   static {
@@ -48,12 +48,12 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
   }
 
   private String host; // required
-  private String uptime_secs; // required
+  private String uptimeSecs; // required
 
   /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
   public enum _Fields implements org.apache.thrift.TFieldIdEnum {
     HOST((short)1, "host"),
-    UPTIME_SECS((short)2, "uptime_secs");
+    UPTIME_SECS((short)2, "uptimeSecs");
 
     private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();
 
@@ -117,7 +117,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
     tmpMap.put(_Fields.HOST, new org.apache.thrift.meta_data.FieldMetaData("host", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
-    tmpMap.put(_Fields.UPTIME_SECS, new org.apache.thrift.meta_data.FieldMetaData("uptime_secs", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.UPTIME_SECS, new org.apache.thrift.meta_data.FieldMetaData("uptimeSecs", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
     metaDataMap = Collections.unmodifiableMap(tmpMap);
     org.apache.thrift.meta_data.FieldMetaData.addStructMetaDataMap(NimbusStat.class, metaDataMap);
@@ -128,11 +128,11 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
 
   public NimbusStat(
     String host,
-    String uptime_secs)
+    String uptimeSecs)
   {
     this();
     this.host = host;
-    this.uptime_secs = uptime_secs;
+    this.uptimeSecs = uptimeSecs;
   }
 
   /**
@@ -142,8 +142,8 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
     if (other.is_set_host()) {
       this.host = other.host;
     }
-    if (other.is_set_uptime_secs()) {
-      this.uptime_secs = other.uptime_secs;
+    if (other.is_set_uptimeSecs()) {
+      this.uptimeSecs = other.uptimeSecs;
     }
   }
 
@@ -154,7 +154,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
   @Override
   public void clear() {
     this.host = null;
-    this.uptime_secs = null;
+    this.uptimeSecs = null;
   }
 
   public String get_host() {
@@ -180,26 +180,26 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
     }
   }
 
-  public String get_uptime_secs() {
-    return this.uptime_secs;
+  public String get_uptimeSecs() {
+    return this.uptimeSecs;
   }
 
-  public void set_uptime_secs(String uptime_secs) {
-    this.uptime_secs = uptime_secs;
+  public void set_uptimeSecs(String uptimeSecs) {
+    this.uptimeSecs = uptimeSecs;
   }
 
-  public void unset_uptime_secs() {
-    this.uptime_secs = null;
+  public void unset_uptimeSecs() {
+    this.uptimeSecs = null;
   }
 
-  /** Returns true if field uptime_secs is set (has been assigned a value) and false otherwise */
-  public boolean is_set_uptime_secs() {
-    return this.uptime_secs != null;
+  /** Returns true if field uptimeSecs is set (has been assigned a value) and false otherwise */
+  public boolean is_set_uptimeSecs() {
+    return this.uptimeSecs != null;
   }
 
-  public void set_uptime_secs_isSet(boolean value) {
+  public void set_uptimeSecs_isSet(boolean value) {
     if (!value) {
-      this.uptime_secs = null;
+      this.uptimeSecs = null;
     }
   }
 
@@ -215,9 +215,9 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
 
     case UPTIME_SECS:
       if (value == null) {
-        unset_uptime_secs();
+        unset_uptimeSecs();
       } else {
-        set_uptime_secs((String)value);
+        set_uptimeSecs((String)value);
       }
       break;
 
@@ -230,7 +230,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
       return get_host();
 
     case UPTIME_SECS:
-      return get_uptime_secs();
+      return get_uptimeSecs();
 
     }
     throw new IllegalStateException();
@@ -246,7 +246,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
     case HOST:
       return is_set_host();
     case UPTIME_SECS:
-      return is_set_uptime_secs();
+      return is_set_uptimeSecs();
     }
     throw new IllegalStateException();
   }
@@ -273,12 +273,12 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
         return false;
     }
 
-    boolean this_present_uptime_secs = true && this.is_set_uptime_secs();
-    boolean that_present_uptime_secs = true && that.is_set_uptime_secs();
-    if (this_present_uptime_secs || that_present_uptime_secs) {
-      if (!(this_present_uptime_secs && that_present_uptime_secs))
+    boolean this_present_uptimeSecs = true && this.is_set_uptimeSecs();
+    boolean that_present_uptimeSecs = true && that.is_set_uptimeSecs();
+    if (this_present_uptimeSecs || that_present_uptimeSecs) {
+      if (!(this_present_uptimeSecs && that_present_uptimeSecs))
         return false;
-      if (!this.uptime_secs.equals(that.uptime_secs))
+      if (!this.uptimeSecs.equals(that.uptimeSecs))
         return false;
     }
 
@@ -294,10 +294,10 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
     if (present_host)
       list.add(host);
 
-    boolean present_uptime_secs = true && (is_set_uptime_secs());
-    list.add(present_uptime_secs);
-    if (present_uptime_secs)
-      list.add(uptime_secs);
+    boolean present_uptimeSecs = true && (is_set_uptimeSecs());
+    list.add(present_uptimeSecs);
+    if (present_uptimeSecs)
+      list.add(uptimeSecs);
 
     return list.hashCode();
   }
@@ -320,12 +320,12 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(is_set_uptime_secs()).compareTo(other.is_set_uptime_secs());
+    lastComparison = Boolean.valueOf(is_set_uptimeSecs()).compareTo(other.is_set_uptimeSecs());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (is_set_uptime_secs()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.uptime_secs, other.uptime_secs);
+    if (is_set_uptimeSecs()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.uptimeSecs, other.uptimeSecs);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -337,11 +337,11 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
     return _Fields.findByThriftId(fieldId);
   }
 
-  public void read(org.apache.thrift.protocol.TProtocol iprot) throws org.apache.thrift.TException {
+  public void read(org.apache.thrift.protocol.TProtocol iprot) throws TException {
     schemes.get(iprot.getScheme()).getScheme().read(iprot, this);
   }
 
-  public void write(org.apache.thrift.protocol.TProtocol oprot) throws org.apache.thrift.TException {
+  public void write(org.apache.thrift.protocol.TProtocol oprot) throws TException {
     schemes.get(oprot.getScheme()).getScheme().write(oprot, this);
   }
 
@@ -358,25 +358,25 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
     }
     first = false;
     if (!first) sb.append(", ");
-    sb.append("uptime_secs:");
-    if (this.uptime_secs == null) {
+    sb.append("uptimeSecs:");
+    if (this.uptimeSecs == null) {
       sb.append("null");
     } else {
-      sb.append(this.uptime_secs);
+      sb.append(this.uptimeSecs);
     }
     first = false;
     sb.append(")");
     return sb.toString();
   }
 
-  public void validate() throws org.apache.thrift.TException {
+  public void validate() throws TException {
     // check for required fields
     if (!is_set_host()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'host' is unset! Struct:" + toString());
+      throw new TProtocolException("Required field 'host' is unset! Struct:" + toString());
     }
 
-    if (!is_set_uptime_secs()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'uptime_secs' is unset! Struct:" + toString());
+    if (!is_set_uptimeSecs()) {
+      throw new TProtocolException("Required field 'uptimeSecs' is unset! Struct:" + toString());
     }
 
     // check for sub-struct validity
@@ -385,7 +385,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
   private void writeObject(java.io.ObjectOutputStream out) throws java.io.IOException {
     try {
       write(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(out)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -393,7 +393,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
   private void readObject(java.io.ObjectInputStream in) throws java.io.IOException, ClassNotFoundException {
     try {
       read(new org.apache.thrift.protocol.TCompactProtocol(new org.apache.thrift.transport.TIOStreamTransport(in)));
-    } catch (org.apache.thrift.TException te) {
+    } catch (TException te) {
       throw new java.io.IOException(te);
     }
   }
@@ -406,7 +406,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
 
   private static class NimbusStatStandardScheme extends StandardScheme<NimbusStat> {
 
-    public void read(org.apache.thrift.protocol.TProtocol iprot, NimbusStat struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol iprot, NimbusStat struct) throws TException {
       org.apache.thrift.protocol.TField schemeField;
       iprot.readStructBegin();
       while (true)
@@ -426,8 +426,8 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
             break;
           case 2: // UPTIME_SECS
             if (schemeField.type == org.apache.thrift.protocol.TType.STRING) {
-              struct.uptime_secs = iprot.readString();
-              struct.set_uptime_secs_isSet(true);
+              struct.uptimeSecs = iprot.readString();
+              struct.set_uptimeSecs_isSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -441,7 +441,7 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
       struct.validate();
     }
 
-    public void write(org.apache.thrift.protocol.TProtocol oprot, NimbusStat struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol oprot, NimbusStat struct) throws TException {
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
@@ -450,9 +450,9 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
         oprot.writeString(struct.host);
         oprot.writeFieldEnd();
       }
-      if (struct.uptime_secs != null) {
+      if (struct.uptimeSecs != null) {
         oprot.writeFieldBegin(UPTIME_SECS_FIELD_DESC);
-        oprot.writeString(struct.uptime_secs);
+        oprot.writeString(struct.uptimeSecs);
         oprot.writeFieldEnd();
       }
       oprot.writeFieldStop();
@@ -470,19 +470,19 @@ public class NimbusStat implements org.apache.thrift.TBase<NimbusStat, NimbusSta
   private static class NimbusStatTupleScheme extends TupleScheme<NimbusStat> {
 
     @Override
-    public void write(org.apache.thrift.protocol.TProtocol prot, NimbusStat struct) throws org.apache.thrift.TException {
+    public void write(org.apache.thrift.protocol.TProtocol prot, NimbusStat struct) throws TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
       oprot.writeString(struct.host);
-      oprot.writeString(struct.uptime_secs);
+      oprot.writeString(struct.uptimeSecs);
     }
 
     @Override
-    public void read(org.apache.thrift.protocol.TProtocol prot, NimbusStat struct) throws org.apache.thrift.TException {
+    public void read(org.apache.thrift.protocol.TProtocol prot, NimbusStat struct) throws TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
       struct.host = iprot.readString();
       struct.set_host_isSet(true);
-      struct.uptime_secs = iprot.readString();
-      struct.set_uptime_secs_isSet(true);
+      struct.uptimeSecs = iprot.readString();
+      struct.set_uptimeSecs_isSet(true);
     }
   }
 

http://git-wip-us.apache.org/repos/asf/storm/blob/7eaf0651/jstorm-core/src/main/java/backtype/storm/generated/NimbusSummary.java
----------------------------------------------------------------------